==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/VerifyOTPMessageRequestParameters.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class VerifyOTPMessageRequestParameters(
    destinationIdentity: __string,
    otp: __string,
    referenceId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters = {
    import VerifyOTPMessageRequestParameters.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
      .builder()
      .destinationIdentity(
        __string.unwrap(destinationIdentity): java.lang.String
      )
      .otp(__string.unwrap(otp): java.lang.String)
      .referenceId(__string.unwrap(referenceId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly =
    zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters
      .wrap(buildAwsValue())
}
object VerifyOTPMessageRequestParameters {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters =
      zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters(
        destinationIdentity,
        otp,
        referenceId
      )
    def destinationIdentity: __string
    def otp: __string
    def referenceId: __string
    def getDestinationIdentity: ZIO[Any, Nothing, __string] =
      ZIO.succeed(destinationIdentity)
    def getOtp: ZIO[Any, Nothing, __string] = ZIO.succeed(otp)
    def getReferenceId: ZIO[Any, Nothing, __string] = ZIO.succeed(referenceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
  ) extends zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly {
    override val destinationIdentity: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.destinationIdentity())
    override val otp: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.otp())
    override val referenceId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.referenceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
  ): zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/VerifyOTPMessageRequestParameters.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class VerifyOTPMessageRequestParameters(
    destinationIdentity: __string,
    otp: __string,
    referenceId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters = {
    import VerifyOTPMessageRequestParameters.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
      .builder()
      .destinationIdentity(destinationIdentity: java.lang.String)
      .otp(otp: java.lang.String)
      .referenceId(referenceId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly =
    zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters
      .wrap(buildAwsValue())
}
object VerifyOTPMessageRequestParameters {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters =
      zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters(
        destinationIdentity,
        otp,
        referenceId
      )
    def destinationIdentity: __string
    def otp: __string
    def referenceId: __string
    def getDestinationIdentity: ZIO[Any, Nothing, __string] =
      ZIO.succeed(destinationIdentity)
    def getOtp: ZIO[Any, Nothing, __string] = ZIO.succeed(otp)
    def getReferenceId: ZIO[Any, Nothing, __string] = ZIO.succeed(referenceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
  ) extends zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly {
    override val destinationIdentity: __string =
      impl.destinationIdentity(): __string
    override val otp: __string = impl.otp(): __string
    override val referenceId: __string = impl.referenceId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOTPMessageRequestParameters
  ): zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly =
    new Wrapper(impl)
}
